@@ -43,17 +43,17 @@ tabcox <- function(x, time, delta, latex = FALSE, xlabels = NULL, decimals = 2,
   
   # Drop observations with missing values for one or more predictors
   locs <- complete.cases(x) & !is.na(time) & !is.na(delta)
-  x <- as.data.frame(x[locs,])
+  x <- as.data.frame(x[locs, ])
   time <- time[locs]
   delta <- delta[locs]
   
   # Get number of levels in each variable in x
   rows <- c()
   for (ii in 1:colx) {
-    if (!is.factor(x[,ii]) | (is.factor(x[,ii]) & length(unique(x[,ii])) == 2)) {
+    if (!is.factor(x[, ii]) | (is.factor(x[, ii]) & length(unique(x[, ii])) == 2)) {
       rows[ii] <- 1
     } else {
-      rows[ii] <- length(unique(x[,ii]))+1
+      rows[ii] <- length(unique(x[, ii]))+1
     }
   }
   
@@ -93,8 +93,8 @@ tabcox <- function(x, time, delta, latex = FALSE, xlabels = NULL, decimals = 2,
   # Standardize variables if necessary
   if (coef == "x") {
     for (ii in 1:colx) {
-      if (!is.factor(x[,ii]) & length(unique(x[,ii])) > 2) {
-        x[,ii] <- (x[,ii]-mean(x[,ii]))/sd(x[,ii])
+      if (!is.factor(x[, ii]) & length(unique(x[, ii])) > 2) {
+        x[, ii] <- (x[, ii]-mean(x[, ii]))/sd(x[, ii])
       }
     }
   }
@@ -103,21 +103,21 @@ tabcox <- function(x, time, delta, latex = FALSE, xlabels = NULL, decimals = 2,
   survobj <- Surv(time = time, event = delta)
   
   # Run Cox PH regression depending on number of x variables
-  if (colx == 1) {fit <- summary(coxph(formula = survobj ~ x[,1]))}
-  if (colx == 2) {fit <- summary(coxph(formula = survobj ~ x[,1] + x[,2]))}
-  if (colx == 3) {fit <- summary(coxph(formula = survobj ~ x[,1] + x[,2] + x[,3]))}
-  if (colx == 4) {fit <- summary(coxph(formula = survobj ~ x[,1] + x[,2] + x[,3] + x[,4]))}
-  if (colx == 5) {fit <- summary(coxph(formula = survobj ~ x[,1] + x[,2] + x[,3] + x[,4] + x[,5]))}
-  if (colx == 6) {fit <- summary(coxph(formula = survobj ~ x[,1] + x[,2] + x[,3] + x[,4] + x[,5] + x[,6]))}
-  if (colx == 7) {fit <- summary(coxph(formula = survobj ~ x[,1] + x[,2] + x[,3] + x[,4] + x[,5] + x[,6] + x[,7]))}
-  if (colx == 8) {fit <- summary(coxph(formula = survobj ~ x[,1] + x[,2] + x[,3] + x[,4] + x[,5] + x[,6] + x[,7] + x[,8]))}
-  if (colx == 9) {fit <- summary(coxph(formula = survobj ~ x[,1] + x[,2] + x[,3] + x[,4] + x[,5] + x[,6] + x[,7] + x[,8] + x[,9]))}
-  if (colx == 10) {fit <- summary(coxph(formula = survobj ~ x[,1] + x[,2] + x[,3] + x[,4] + x[,5] + x[,6] + x[,7] + x[,8] + x[,9] + x[,10]))}
+  if (colx == 1) {fit <- summary(coxph(formula = survobj ~ x[, 1]))}
+  if (colx == 2) {fit <- summary(coxph(formula = survobj ~ x[, 1] + x[, 2]))}
+  if (colx == 3) {fit <- summary(coxph(formula = survobj ~ x[, 1] + x[, 2] + x[, 3]))}
+  if (colx == 4) {fit <- summary(coxph(formula = survobj ~ x[, 1] + x[, 2] + x[, 3] + x[, 4]))}
+  if (colx == 5) {fit <- summary(coxph(formula = survobj ~ x[, 1] + x[, 2] + x[, 3] + x[, 4] + x[, 5]))}
+  if (colx == 6) {fit <- summary(coxph(formula = survobj ~ x[, 1] + x[, 2] + x[, 3] + x[, 4] + x[, 5] + x[, 6]))}
+  if (colx == 7) {fit <- summary(coxph(formula = survobj ~ x[, 1] + x[, 2] + x[, 3] + x[, 4] + x[, 5] + x[, 6] + x[, 7]))}
+  if (colx == 8) {fit <- summary(coxph(formula = survobj ~ x[, 1] + x[, 2] + x[, 3] + x[, 4] + x[, 5] + x[, 6] + x[, 7] + x[, 8]))}
+  if (colx == 9) {fit <- summary(coxph(formula = survobj ~ x[, 1] + x[, 2] + x[, 3] + x[, 4] + x[, 5] + x[, 6] + x[, 7] + x[, 8] + x[, 9]))}
+  if (colx == 10) {fit <- summary(coxph(formula = survobj ~ x[, 1] + x[, 2] + x[, 3] + x[, 4] + x[, 5] + x[, 6] + x[, 7] + x[, 8] + x[, 9] + x[, 10]))}
   
   # Initialize table
   tbl <- matrix("", nrow = sum(rows), ncol = 7)
-  tbl[1,2] <- sum(locs)
-  tbl[1,3] <- sum(delta)
+  tbl[1, 2] <- sum(locs)
+  tbl[1, 3] <- sum(delta)
   
   # Enter values in table
   coef.index <- 0
@@ -126,30 +126,30 @@ tabcox <- function(x, time, delta, latex = FALSE, xlabels = NULL, decimals = 2,
     if (rows[ii] == 1) {
       coef.index <- coef.index+1
       tbl.index <- tbl.index+1
-      beta <- fit$coefficients[coef.index,1]
-      se <- fit$coefficients[coef.index,3]
+      beta <- fit$coefficients[coef.index, 1]
+      se <- fit$coefficients[coef.index, 3]
       hr <- exp(beta)
-      p <- fit$coefficients[coef.index,5]
-      tbl[tbl.index,4] <- paste(sprintf(spf, beta), " (", sprintf(spf, se), ")", sep = "")
-      tbl[tbl.index,5] <- sprintf(spf, hr)
-      tbl[tbl.index,6] <- paste("(", sprintf(spf, exp(beta-1.96*se)), ", ", sprintf(spf, exp(beta+1.96*se)), ")", sep = "")
-      tbl[tbl.index,7] <- formatp(p = p, cuts = p.cuts, decimals = p.decimals, lowerbound = p.lowerbound,
-                                  leading0 = p.leading0, avoid1 = p.avoid1)
+      p <- fit$coefficients[coef.index, 5]
+      tbl[tbl.index, 4] <- paste(sprintf(spf, beta), " (", sprintf(spf, se), ")", sep = "")
+      tbl[tbl.index, 5] <- sprintf(spf, hr)
+      tbl[tbl.index, 6] <- paste("(", sprintf(spf, exp(beta-1.96*se)), ", ", sprintf(spf, exp(beta+1.96*se)), ")", sep = "")
+      tbl[tbl.index, 7] <- formatp(p = p, cuts = p.cuts, decimals = p.decimals, lowerbound = p.lowerbound,
+                                   leading0 = p.leading0, avoid1 = p.avoid1)
     } else {
-      tbl[(tbl.index+2),4:7] <- "-"
+      tbl[(tbl.index+2), 4:7] <- "-"
       tbl.index <- tbl.index+2
       for (jj in 1:(rows[ii]-2)) {
         coef.index <- coef.index+1
         tbl.index <- tbl.index+1
-        beta <- fit$coefficients[coef.index,1]
-        se <- fit$coefficients[coef.index,3]
+        beta <- fit$coefficients[coef.index, 1]
+        se <- fit$coefficients[coef.index, 3]
         hr <- exp(beta)
-        p <- fit$coefficients[coef.index,5]
-        tbl[tbl.index,4] <- paste(sprintf(spf, beta), " (", sprintf(spf, se), ")", sep = "")
-        tbl[tbl.index,5] <- sprintf(spf, hr)
-        tbl[tbl.index,6] <- paste("(", sprintf(spf, exp(beta-1.96*se)), ", ", sprintf(spf, exp(beta+1.96*se)), ")", sep = "")
-        tbl[tbl.index,7] <- formatp(p = p, cuts = p.cuts, decimals = p.decimals, lowerbound = p.lowerbound,
-                                    leading0 = p.leading0, avoid1 = p.avoid1)
+        p <- fit$coefficients[coef.index, 5]
+        tbl[tbl.index, 4] <- paste(sprintf(spf, beta), " (", sprintf(spf, se), ")", sep = "")
+        tbl[tbl.index, 5] <- sprintf(spf, hr)
+        tbl[tbl.index, 6] <- paste("(", sprintf(spf, exp(beta-1.96*se)), ", ", sprintf(spf, exp(beta+1.96*se)), ")", sep = "")
+        tbl[tbl.index, 7] <- formatp(p = p, cuts = p.cuts, decimals = p.decimals, lowerbound = p.lowerbound,
+                                     leading0 = p.leading0, avoid1 = p.avoid1)
       }
     }
   }
@@ -162,21 +162,21 @@ tabcox <- function(x, time, delta, latex = FALSE, xlabels = NULL, decimals = 2,
   
   # Drop particular columns if requested
   if (n == FALSE) {
-    tbl <- tbl[,colnames(tbl) != "N", drop = FALSE]
+    tbl <- tbl[, colnames(tbl) != "N", drop = FALSE]
   }
   if (events == FALSE) {
-    tbl <- tbl[,colnames(tbl) != "Events", drop = FALSE]
+    tbl <- tbl[, colnames(tbl) != "Events", drop = FALSE]
   }
   
   # If latex is TRUE, do some re-formatting
   if (latex == TRUE) {
-    plocs = which(substr(tbl[,"P"],1,1) == "<")
+    plocs <- which(substr(tbl[, "P"], 1, 1) == "<")
     if (length(plocs) > 0) {
-      tbl[plocs,"P"] = paste("$<$", substring(tbl[plocs,"P"],2), sep = "")
+      tbl[plocs, "P"] <- paste("$<$", substring(tbl[plocs, "P"], 2), sep = "")
     }
-    spacelocs = which(substr(tbl[,"Variable"],1,2) == "  ")
+    spacelocs <- which(substr(tbl[, "Variable"], 1, 2) == "  ")
     if (length(spacelocs) > 0) {
-      tbl[spacelocs,"Variable"] = paste("\\hskip .3cm ", substring(tbl[spacelocs,"Variable"], 3), sep = "")
+      tbl[spacelocs, "Variable"] <- paste("\\hskip .3cm ", substring(tbl[spacelocs, "Variable"], 3), sep = "")
     }
   }
   
